==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d9/d33/rail_8h.js <==
var rail_8h =
[
    [ "RailtypeInfo", "d2/ded/classRailtypeInfo.html", "d2/ded/classRailtypeInfo" ],
    [ "FOR_ALL_SORTED_RAILTYPES", "d9/d33/rail_8h.html#a5c49243d875a647030414ca541123888", null ],
    [ "RailTypeLabelList", "d9/d33/rail_8h.html#a94e59f548f2c5eb21df0de4a1d9457d3", null ],
    [ "RailFenceOffset", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67", [
      [ "RFO_FLAT_X_NW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67aece35a8b5b4b3cbc428ddff1dba37c1f", null ],
      [ "RFO_FLAT_Y_NE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a13790d6b71f8b389b1bc429f3c700332", null ],
      [ "RFO_FLAT_LEFT", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67adf922c9dbb9242b852205b9c583f1875", null ],
      [ "RFO_FLAT_UPPER", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67aab8ab4e8f1623b4c4042073fd6b08dc5", null ],
      [ "RFO_SLOPE_SW_NW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67af110980ea323eaec6ca9df00695c27f9", null ],
      [ "RFO_SLOPE_SE_NE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67abb62a9d126cd6dd1afefbbc55bec69d4", null ],
      [ "RFO_SLOPE_NE_NW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67ae19dc763954d61759e39ae28ce34350d", null ],
      [ "RFO_SLOPE_NW_NE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a56c66a479b727b5cd23128d863942e90", null ],
      [ "RFO_FLAT_X_SE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a2cc18efcf855d9c234868a048f3fee8b", null ],
      [ "RFO_FLAT_Y_SW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67ac06473f42fe20e0a4321ff6b7bff0934", null ],
      [ "RFO_FLAT_RIGHT", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a0382f0ed02c0435c53739f78577ba0c1", null ],
      [ "RFO_FLAT_LOWER", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a9e9dd7908b7f441713d6f2abfb705a5c", null ],
      [ "RFO_SLOPE_SW_SE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67aa041bf3ddf490bcaeb5814ee49d231e6", null ],
      [ "RFO_SLOPE_SE_SW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a5c6fab622b090d28aa54b9160d30724f", null ],
      [ "RFO_SLOPE_NE_SE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a861be123709b2c74820b432360a8c306", null ],
      [ "RFO_SLOPE_NW_SW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a1f6cb3f08957c1f92d4012b88f47948f", null ]
    ] ],
    [ "RailTrackBridgeOffset", "d9/d33/rail_8h.html#a221dddc8d41ba338021cadf527fd7c33", [
      [ "RTBO_X", "d9/d33/rail_8h.html#a221dddc8d41ba338021cadf527fd7c33adef930b8b4dfe331fc35536d796551a4", null ],
      [ "RTBO_Y", "d9/d33/rail_8h.html#a221dddc8d41ba338021cadf527fd7c33a9b192b1b5ab94d25d28d3ba4ec8bdd8b", null ],
      [ "RTBO_SLOPE", "d9/d33/rail_8h.html#a221dddc8d41ba338021cadf527fd7c33adfea6b7255aacd653109fe4ad7307ee8", null ]
    ] ],
    [ "RailTrackOffset", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4", [
      [ "RTO_X", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ae62d6ede749803c79e858a6b510af418", null ],
      [ "RTO_Y", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a27df5c57dcb0f6ef669ac9e09d235139", null ],
      [ "RTO_N", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4aff6caa51f2bf0083a97dbd1fded1ce59", null ],
      [ "RTO_S", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a356daf698280c1dc43c93b51fe8d40ce", null ],
      [ "RTO_E", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a8baca554aa47aa18a7b016247974eb6a", null ],
      [ "RTO_W", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a922c864f91c99a21de76e1a36c364704", null ],
      [ "RTO_SLOPE_NE", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ae26abdd32ac6c4e53b54b6b3732ebf6c", null ],
      [ "RTO_SLOPE_SE", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a6daf8d4032903f04c81327d92e648ad3", null ],
      [ "RTO_SLOPE_SW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ad1ebe22e1a676e6c9eab7356cf3416b2", null ],
      [ "RTO_SLOPE_NW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ad3c6d4d33d7a92e472c5bc137cf19160", null ],
      [ "RTO_CROSSING_XY", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4aaede0e25d94a36a87e5fcd87ee48a70e", null ],
      [ "RTO_JUNCTION_SW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a6226fa84a7ca9ee201c75e16308a216f", null ],
      [ "RTO_JUNCTION_NE", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a4d49ef63a52746724c0ab81bba341d72", null ],
      [ "RTO_JUNCTION_SE", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4add803312af1cb2aa3a8222a34d6ab005", null ],
      [ "RTO_JUNCTION_NW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ad512dc191359d6e6c37775224d5e4907", null ],
      [ "RTO_JUNCTION_NSEW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a5aac99573feb56664f0ad3247e09739d", null ]
    ] ],
    [ "RailTypeFlags", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2", [
      [ "RTF_CATENARY", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2af84ec9e6488e238e56f3d0bb4e47c837", null ],
      [ "RTF_NO_LEVEL_CROSSING", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a72ec862979b08bc8ac49fc9c923b7683", null ],
      [ "RTF_HIDDEN", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a74aab59f6e4cf418d7f3db1594ba1224", null ],
      [ "RTFB_NONE", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a9b28920186a571bb188d3e90f0cf33eb", null ],
      [ "RTFB_CATENARY", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a932a3b1199188285031f93c1786028c0", null ],
      [ "RTFB_NO_LEVEL_CROSSING", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a17f59efb9af80b9c3dd43e363294df03", null ],
      [ "RTFB_HIDDEN", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2ac1acf7753bfe14b421306943ab0827be", null ]
    ] ],
    [ "RailTypeSpriteGroup", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0", [
      [ "RTSG_CURSORS", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a26f9135f597a45f34c9e964c61e48d91", null ],
      [ "RTSG_OVERLAY", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0aa4252e4b4cba5e88928c4516b4dc2882", null ],
      [ "RTSG_GROUND", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a1a865c51f079c6bfe0f95d9d6804563e", null ],
      [ "RTSG_TUNNEL", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a7d9a2eafbcd396e165eed6cf9a12cda3", null ],
      [ "RTSG_WIRES", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a9d55ebc7452d0e16fbf0f814adeb9891", null ],
      [ "RTSG_PYLONS", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a1c7d683be7c86193862ca7d85ef11b15", null ],
      [ "RTSG_BRIDGE", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0ad18551741d2fc981febf878d1f7c8613", null ],
      [ "RTSG_CROSSING", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a611f25d92c04e567bcec5e480dffec18", null ],
      [ "RTSG_DEPOT", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0ac0786001b66f1a5b38e7e3f1109818ec", null ],
      [ "RTSG_FENCES", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0aef82fe53379b8d18cc04dcb4ba8fe3de", null ],
      [ "RTSG_TUNNEL_PORTAL", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0ad4cd0627b6307dfd83faf0eb46fe676d", null ],
      [ "RTSG_SIGNALS", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0aa515a106a75cb4f05b365c83b0bfbfc7", null ],
      [ "RTSG_END", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a0af02b0f322ffdf127d8f465f3a7590b", null ]
    ] ],
    [ "AddDateIntroducedRailTypes", "d9/d33/rail_8h.html#a09129a008e50b295b3f3f2b49dad9be7", null ],
    [ "AllocateRailType", "d9/d33/rail_8h.html#a4c3553e729576842c00d8f43c7ddd74c", null ],
    [ "DrawTrainDepotSprite", "d9/d33/rail_8h.html#a61cf2d46af5690b786b28260ca53141c", null ],
    [ "GetBestRailtype", "d9/d33/rail_8h.html#ab27bf3554532accc1948eac6cf03b938", null ],
    [ "GetCompanyRailtypes", "d9/d33/rail_8h.html#ae23b5b52728e896a615c78e6a5236909", null ],
    [ "GetRailFoundation", "d9/d33/rail_8h.html#ad9fbfcc25cbdeed8650a4b9a438d42c3", null ],
    [ "GetRailTypeByLabel", "d9/d33/rail_8h.html#ae113099c3214b54b3753faf5a2527542", null ],
    [ "GetRailTypeInfo", "d9/d33/rail_8h.html#a5693dc2dbadbb91c469ac87a80aaf2f9", null ],
    [ "HasAnyRailtypesAvail", "d9/d33/rail_8h.html#afbb82c498dc13beae88ed1e941adb98d", null ],
    [ "HasPowerOnRail", "d9/d33/rail_8h.html#ab85e4004389037e4f81f921bfdcda1c1", null ],
    [ "HasRailtypeAvail", "d9/d33/rail_8h.html#adad4f06eb9fe4681f38aca5f0fc8a8b6", null ],
    [ "InitRailTypes", "d9/d33/rail_8h.html#a7ff4e557864fffcf6e6a6615d20f0e23", null ],
    [ "IsCompatibleRail", "d9/d33/rail_8h.html#a7ac061a1b5b962978d3e6c9da8fcdb9a", null ],
    [ "RailBuildCost", "d9/d33/rail_8h.html#ab044b1dda48c84dc610a5d30cbe35472", null ],
    [ "RailClearCost", "d9/d33/rail_8h.html#a71762003510ea0cf2e0d7804ccbddbe4", null ],
    [ "RailConvertCost", "d9/d33/rail_8h.html#ab1616ad8ed5af2dbcd4b62f5961a8999", null ],
    [ "RailMaintenanceCost", "d9/d33/rail_8h.html#a0048d5fecc0dddd537500e89f0c74324", null ],
    [ "RailNoLevelCrossings", "d9/d33/rail_8h.html#a392238343033c8f4e35c51ef9df7a66b", null ],
    [ "ResetRailTypes", "d9/d33/rail_8h.html#aa13d9e37ffb4d87cbf27f1c3910c5ce7", null ],
    [ "SignalMaintenanceCost", "d9/d33/rail_8h.html#ad1c5f934eb6a4574d06822b3b6548de5", null ],
    [ "TicksToLeaveDepot", "d9/d33/rail_8h.html#a0787b3183de05d67e83e003e85a3005d", null ],
    [ "ValParamRailtype", "d9/d33/rail_8h.html#a61120aacc59523a2bde03bda1cbab670", null ],
    [ "_railtypes_hidden_mask", "d9/d33/rail_8h.html#a4e83894f8a4064f4b6bc8d9c09b4abcb", null ],
    [ "_sorted_railtypes", "d9/d33/rail_8h.html#ab7e0d33b51f850c95edcb0ce97560160", null ],
    [ "_sorted_railtypes_size", "d9/d33/rail_8h.html#a9c232ff9c788f472bf054fdb739ab895", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d9/d33/rail_8h.js <==
var rail_8h =
[
    [ "RailtypeInfo", "d2/ded/classRailtypeInfo.html", "d2/ded/classRailtypeInfo" ],
    [ "FOR_ALL_SORTED_RAILTYPES", "d9/d33/rail_8h.html#a5c49243d875a647030414ca541123888", null ],
    [ "RailTypeLabelList", "d9/d33/rail_8h.html#a904638a018d38b45509092a618e6433d", null ],
    [ "RailFenceOffset", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67", [
      [ "RFO_FLAT_X_NW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67aece35a8b5b4b3cbc428ddff1dba37c1f", null ],
      [ "RFO_FLAT_Y_NE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a13790d6b71f8b389b1bc429f3c700332", null ],
      [ "RFO_FLAT_LEFT", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67adf922c9dbb9242b852205b9c583f1875", null ],
      [ "RFO_FLAT_UPPER", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67aab8ab4e8f1623b4c4042073fd6b08dc5", null ],
      [ "RFO_SLOPE_SW_NW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67af110980ea323eaec6ca9df00695c27f9", null ],
      [ "RFO_SLOPE_SE_NE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67abb62a9d126cd6dd1afefbbc55bec69d4", null ],
      [ "RFO_SLOPE_NE_NW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67ae19dc763954d61759e39ae28ce34350d", null ],
      [ "RFO_SLOPE_NW_NE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a56c66a479b727b5cd23128d863942e90", null ],
      [ "RFO_FLAT_X_SE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a2cc18efcf855d9c234868a048f3fee8b", null ],
      [ "RFO_FLAT_Y_SW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67ac06473f42fe20e0a4321ff6b7bff0934", null ],
      [ "RFO_FLAT_RIGHT", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a0382f0ed02c0435c53739f78577ba0c1", null ],
      [ "RFO_FLAT_LOWER", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a9e9dd7908b7f441713d6f2abfb705a5c", null ],
      [ "RFO_SLOPE_SW_SE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67aa041bf3ddf490bcaeb5814ee49d231e6", null ],
      [ "RFO_SLOPE_SE_SW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a5c6fab622b090d28aa54b9160d30724f", null ],
      [ "RFO_SLOPE_NE_SE", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a861be123709b2c74820b432360a8c306", null ],
      [ "RFO_SLOPE_NW_SW", "d9/d33/rail_8h.html#ad0be65cdf9bdf52e8b5528a205d21d67a1f6cb3f08957c1f92d4012b88f47948f", null ]
    ] ],
    [ "RailTrackBridgeOffset", "d9/d33/rail_8h.html#a221dddc8d41ba338021cadf527fd7c33", [
      [ "RTBO_X", "d9/d33/rail_8h.html#a221dddc8d41ba338021cadf527fd7c33adef930b8b4dfe331fc35536d796551a4", null ],
      [ "RTBO_Y", "d9/d33/rail_8h.html#a221dddc8d41ba338021cadf527fd7c33a9b192b1b5ab94d25d28d3ba4ec8bdd8b", null ],
      [ "RTBO_SLOPE", "d9/d33/rail_8h.html#a221dddc8d41ba338021cadf527fd7c33adfea6b7255aacd653109fe4ad7307ee8", null ]
    ] ],
    [ "RailTrackOffset", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4", [
      [ "RTO_X", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ae62d6ede749803c79e858a6b510af418", null ],
      [ "RTO_Y", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a27df5c57dcb0f6ef669ac9e09d235139", null ],
      [ "RTO_N", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4aff6caa51f2bf0083a97dbd1fded1ce59", null ],
      [ "RTO_S", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a356daf698280c1dc43c93b51fe8d40ce", null ],
      [ "RTO_E", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a8baca554aa47aa18a7b016247974eb6a", null ],
      [ "RTO_W", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a922c864f91c99a21de76e1a36c364704", null ],
      [ "RTO_SLOPE_NE", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ae26abdd32ac6c4e53b54b6b3732ebf6c", null ],
      [ "RTO_SLOPE_SE", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a6daf8d4032903f04c81327d92e648ad3", null ],
      [ "RTO_SLOPE_SW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ad1ebe22e1a676e6c9eab7356cf3416b2", null ],
      [ "RTO_SLOPE_NW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ad3c6d4d33d7a92e472c5bc137cf19160", null ],
      [ "RTO_CROSSING_XY", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4aaede0e25d94a36a87e5fcd87ee48a70e", null ],
      [ "RTO_JUNCTION_SW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a6226fa84a7ca9ee201c75e16308a216f", null ],
      [ "RTO_JUNCTION_NE", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a4d49ef63a52746724c0ab81bba341d72", null ],
      [ "RTO_JUNCTION_SE", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4add803312af1cb2aa3a8222a34d6ab005", null ],
      [ "RTO_JUNCTION_NW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4ad512dc191359d6e6c37775224d5e4907", null ],
      [ "RTO_JUNCTION_NSEW", "d9/d33/rail_8h.html#a964fb7707906f9e3bdf05c1b329992a4a5aac99573feb56664f0ad3247e09739d", null ]
    ] ],
    [ "RailTypeFlags", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2", [
      [ "RTF_CATENARY", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2af84ec9e6488e238e56f3d0bb4e47c837", null ],
      [ "RTF_NO_LEVEL_CROSSING", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a72ec862979b08bc8ac49fc9c923b7683", null ],
      [ "RTF_HIDDEN", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a74aab59f6e4cf418d7f3db1594ba1224", null ],
      [ "RTF_NO_SPRITE_COMBINE", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2aa52bd0db73d0e6bded44fd86c3328367", null ],
      [ "RTF_ALLOW_90DEG", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2ab6cc98cf93e4783af3c0151fc0e63dac", null ],
      [ "RTF_DISALLOW_90DEG", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2ae37dd647e3d651a87e542f4093c0980f", null ],
      [ "RTFB_NONE", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a9b28920186a571bb188d3e90f0cf33eb", null ],
      [ "RTFB_CATENARY", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a932a3b1199188285031f93c1786028c0", null ],
      [ "RTFB_NO_LEVEL_CROSSING", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a17f59efb9af80b9c3dd43e363294df03", null ],
      [ "RTFB_HIDDEN", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2ac1acf7753bfe14b421306943ab0827be", null ],
      [ "RTFB_NO_SPRITE_COMBINE", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a4917059fd4f09461ef82fdfe1250c109", null ],
      [ "RTFB_ALLOW_90DEG", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a35669356498af073beeefe57da24a8fe", null ],
      [ "RTFB_DISALLOW_90DEG", "d9/d33/rail_8h.html#acc1471ac707edbd37d5f7c003ee05ca2a39db310d0d05a0f3c289bf7a402fcc85", null ]
    ] ],
    [ "RailTypeSpriteGroup", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0", [
      [ "RTSG_CURSORS", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a26f9135f597a45f34c9e964c61e48d91", null ],
      [ "RTSG_OVERLAY", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0aa4252e4b4cba5e88928c4516b4dc2882", null ],
      [ "RTSG_GROUND", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a1a865c51f079c6bfe0f95d9d6804563e", null ],
      [ "RTSG_TUNNEL", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a7d9a2eafbcd396e165eed6cf9a12cda3", null ],
      [ "RTSG_WIRES", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a9d55ebc7452d0e16fbf0f814adeb9891", null ],
      [ "RTSG_PYLONS", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a1c7d683be7c86193862ca7d85ef11b15", null ],
      [ "RTSG_BRIDGE", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0ad18551741d2fc981febf878d1f7c8613", null ],
      [ "RTSG_CROSSING", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a611f25d92c04e567bcec5e480dffec18", null ],
      [ "RTSG_DEPOT", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0ac0786001b66f1a5b38e7e3f1109818ec", null ],
      [ "RTSG_FENCES", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0aef82fe53379b8d18cc04dcb4ba8fe3de", null ],
      [ "RTSG_TUNNEL_PORTAL", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0ad4cd0627b6307dfd83faf0eb46fe676d", null ],
      [ "RTSG_SIGNALS", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0aa515a106a75cb4f05b365c83b0bfbfc7", null ],
      [ "RTSG_GROUND_COMPLETE", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a4f1cc87869bef1b0d299bf3dc1ff05f6", null ],
      [ "RTSG_END", "d9/d33/rail_8h.html#a0a2f676007276ec255cf5d4d3f7847b0a0af02b0f322ffdf127d8f465f3a7590b", null ]
    ] ],
    [ "AddDateIntroducedRailTypes", "d9/d33/rail_8h.html#a09129a008e50b295b3f3f2b49dad9be7", null ],
    [ "AllocateRailType", "d9/d33/rail_8h.html#a4c3553e729576842c00d8f43c7ddd74c", null ],
    [ "DrawTrainDepotSprite", "d9/d33/rail_8h.html#a61cf2d46af5690b786b28260ca53141c", null ],
    [ "GetCompanyRailtypes", "d9/d33/rail_8h.html#a1bd82b10edc21d9674d8732b030f31d1", null ],
    [ "GetRailFoundation", "d9/d33/rail_8h.html#ad9fbfcc25cbdeed8650a4b9a438d42c3", null ],
    [ "GetRailTypeByLabel", "d9/d33/rail_8h.html#ae113099c3214b54b3753faf5a2527542", null ],
    [ "GetRailTypeInfo", "d9/d33/rail_8h.html#a5693dc2dbadbb91c469ac87a80aaf2f9", null ],
    [ "GetRailTypes", "d9/d33/rail_8h.html#ad4668173be5c89cfe9e1709f23d6ee93", null ],
    [ "HasAnyRailtypesAvail", "d9/d33/rail_8h.html#afbb82c498dc13beae88ed1e941adb98d", null ],
    [ "HasPowerOnRail", "d9/d33/rail_8h.html#ab85e4004389037e4f81f921bfdcda1c1", null ],
    [ "HasRailtypeAvail", "d9/d33/rail_8h.html#adad4f06eb9fe4681f38aca5f0fc8a8b6", null ],
    [ "InitRailTypes", "d9/d33/rail_8h.html#a7ff4e557864fffcf6e6a6615d20f0e23", null ],
    [ "IsCompatibleRail", "d9/d33/rail_8h.html#a7ac061a1b5b962978d3e6c9da8fcdb9a", null ],
    [ "Rail90DegTurnDisallowed", "d9/d33/rail_8h.html#a5474a6b0934e07d9b2036a6a979cd466", null ],
    [ "RailBuildCost", "d9/d33/rail_8h.html#ab044b1dda48c84dc610a5d30cbe35472", null ],
    [ "RailClearCost", "d9/d33/rail_8h.html#a71762003510ea0cf2e0d7804ccbddbe4", null ],
    [ "RailConvertCost", "d9/d33/rail_8h.html#ab1616ad8ed5af2dbcd4b62f5961a8999", null ],
    [ "RailMaintenanceCost", "d9/d33/rail_8h.html#a0048d5fecc0dddd537500e89f0c74324", null ],
    [ "RailNoLevelCrossings", "d9/d33/rail_8h.html#a392238343033c8f4e35c51ef9df7a66b", null ],
    [ "ResetRailTypes", "d9/d33/rail_8h.html#aa13d9e37ffb4d87cbf27f1c3910c5ce7", null ],
    [ "SignalMaintenanceCost", "d9/d33/rail_8h.html#ad1c5f934eb6a4574d06822b3b6548de5", null ],
    [ "TicksToLeaveDepot", "d9/d33/rail_8h.html#a0787b3183de05d67e83e003e85a3005d", null ],
    [ "ValParamRailtype", "d9/d33/rail_8h.html#a61120aacc59523a2bde03bda1cbab670", null ],
    [ "_railtypes_hidden_mask", "d9/d33/rail_8h.html#a4e83894f8a4064f4b6bc8d9c09b4abcb", null ],
    [ "_sorted_railtypes", "d9/d33/rail_8h.html#a568912e9d33bab965272859fcd122be6", null ]
];
